/* css */

/*
	-sprite-set-id: lores2;
	-sprite-set-src: url(lores2.png);
*/

.common
{
	/*
		-sprite-set-ref: lores2;
		-sprite-block-id: common;
	*/
	padding: 20px 10px 20px 10px;
	max-width: 20px; height: 20px;
	background-repeat: no-repeat;
	background-position: left top;
}

.specific
{
	/* -sprite-block-ref: common; */
	background-image: url(test-active.png);
}

.specific:hover
{
	/* -sprite-block-ref: common; */
	background-image: url(test-hover.png);
}

BODY
{
	margin: 0px;
	padding: 0px;
	padding-left: 10px;
}

p.spriteset
{
	overflow: scroll; max-height: 200px;
	/* max-width:100%; height: auto;" */
	background: rgba(192, 192, 192, 0.75);
}

BODY .head DIV.box
{
		margin-bottom: 5px;
}

.cf
{
	overflow: hidden;
	position: relative;
}
.cf .cfi
{
	padding-left: 100px;
}
.cf .cfi .cfi
{
	padding-left: 0px;
}

.cfi
{
	float: left;
	overflow: hidden;
}

.cf .box
{
	float: left;
	margin: 20px;
	cursor: pointer;
	/* padding: 5px; */
	/* padding still buggy */
	border: 3px solid #339999;
	width: 35px; height: 35px;
	background-color: rgba(192, 192, 192, 0.75);

	-webkit-transition: margin 0.25s ease-in-out, padding 0.25s ease-in-out;
	-moz-transition: margin 0.25s ease-in-out, padding 0.25s ease-in-out;
	-o-transition: margin 0.25s ease-in-out, padding 0.25s ease-in-out;
	-ms-transition: margin 0.25s ease-in-out, padding 0.25s ease-in-out;
	transition: margin 0.25s ease-in-out, padding 0.25s ease-in-out;
}

.cf .flex-x
{
	border-top-color: #FF0000;
	border-bottom-color: #FF0000;
}

.cf .flex-x:hover
{
	margin-left: 0px;
	margin-right: 0px;
	padding-right: 45px;
}

.cf .flex-y
{
	border-left-color: #FF0000;
	border-right-color: #FF0000;
}

.cf .flex-y:hover
{
	margin-top: 0px;
	margin-bottom: 0px;
	padding-bottom: 45px;
}

.cf .flex-xy
{
	border-top-color: #FF0000;
	border-bottom-color: #FF0000;
	border-left-color: #FF0000;
	border-right-color: #FF0000;
}

.cf .flex-xy:hover
{
	margin-top: 0px;
	margin-bottom: 0px;
	padding-bottom: 45px;
	margin-left: 0px;
	margin-right: 0px;
	padding-right: 45px;
}

.toggle A
{
	margin: -4px 0px;
	padding: 4px 0px;
	display: block;
	font-size: 10px;
	line-height: 12px;
	font-family: verdana, arial;
}

.cf DIV.row-head
{
	top: 0px;
	position: absolute;
	width: 75px;
	min-height: 36px;
	height: auto;
	padding: 4px 0px 5px;
	font-size: 10px;
	line-height: 12px;
	font-family: verdana, arial;
	text-align: center;
	margin-left: 10px;
	margin-right: 20px;
}

.head DIV.row-head
{
	min-height: 0px;
	padding: 4px 0px 5px;
}

.cf DIV.col-head
{
	float: left;
	display: block;
	width: 136px;
	height: auto;
	padding: 4px 0px 5px;
	font-size: 10px;
	line-height: 12px;
	font-family: verdana, arial;
	text-align: center;
}

.sr
{
	width: 0px !important;
	height: 0px !important;
	display: block !important;
	overflow: hidden !important;
}

/**********/

.sprite-flex-left,
.sprite-flex-top,
.sprite-flex-right,
.sprite-flex-bottom,
.sprite-flex-bottom-right
{
	float: left;
	margin: 20px;
	border: 3px solid #339999;
	background-color: #CCCCCC;
}

A
{
	font: 14px verdana;
	text-decoration: none;
}

A:focus, A:hover
{
	text-decoration: underline;
}

.toggle A
{
	color: #FF0000;
	text-transform: uppercase;
	text-decoration: underline;
}